@@ -10,7 +10,7 @@ Created on Wed Apr  1 14:56:15 2020
 """
 
 from .version import __version__
-from pypims import flood, IO
+from . import flood, IO
 
 __all__ = [
   '__version__',
